==> tfx-cli-0.1.2.tgz: package/lib/connection.js <==
/// <reference path="../../definitions/vso-node-api/vso-node-api.d.ts"/>
var inputs = require('./inputs');
var Q = require('q');
var url = require('url');
var apim = require('vso-node-api/WebApi');
var cm = require('./diskcache');
var cache = new cm.DiskCache('tfx');
var TfsConnection = (function () {
    function TfsConnection(collectionUrl, credentials) {
        this.collectionUrl = collectionUrl;
        this.credentials = credentials;
        switch (credentials.type) {
            case "basic":
                var basicCreds = credentials;
                this.authHandler = apim.getBasicHandler(basicCreds.username, basicCreds.password);
                break;
            case "pat":
                var patCreds = credentials;
                this.authHandler = apim.getBasicHandler("OAuth", patCreds.token);
                break;
        }
        // TODO: validate url
        var purl = url.parse(collectionUrl);
        if (!purl.protocol || !purl.host) {
            throw new Error('Invalid url');
        }
        // TODO: handle on prem /tfs
        this.accountUrl = purl.protocol + '//' + purl.host;
    }
    return TfsConnection;
})();
exports.TfsConnection = TfsConnection;
var result;
function getCollectionUrl() {
    var defer = Q.defer();
    return this.getCachedUrl().then(function (url) {
        return url ? url : promptForUrl();
    });
    return defer.promise;
}
exports.getCollectionUrl = getCollectionUrl;
function getCachedUrl() {
    var defer = Q.defer();
    if (process.env['TFS_BYPASS_CACHE']) {
        defer.resolve('');
    }
    cache.getItem('cache', 'connection').then(function (url) {
        defer.resolve(url);
    }).fail(function (err) {
        defer.resolve('');
    });
    return defer.promise;
}
exports.getCachedUrl = getCachedUrl;
function promptForUrl() {
    var defer = Q.defer();
    var promise = defer.promise;
    if (result) {
        defer.resolve(result);
        return promise;
    }
    var credInputs = [
        {
            name: 'collection',
            description: 'collection url',
            arg: 'collection',
            type: 'string',
            req: true
        }
    ];
    inputs.get(credInputs, function (err, result) {
        if (err) {
            defer.reject(err);
            return;
        }
        defer.resolve(result['collection']);
    });
    return promise;
}
exports.promptForUrl = promptForUrl;

==> tfx-cli-0.1.6.tgz: package/lib/connection.js <==
/// <reference path="../../definitions/vso-node-api/vso-node-api.d.ts"/>
var inputs = require('./inputs');
var Q = require('q');
var url = require('url');
var apim = require('vso-node-api/WebApi');
var cm = require('./diskcache');
var trace = require('./trace');
var cache = new cm.DiskCache('tfx');
var TfsConnection = (function () {
    function TfsConnection(collectionUrl, credentials) {
        this.collectionUrl = collectionUrl;
        this.credentials = credentials;
        switch (credentials.type) {
            case "basic":
                trace('Using basic creds');
                var basicCreds = credentials;
                this.authHandler = apim.getBasicHandler(basicCreds.username, basicCreds.password);
                break;
            case "pat":
                trace('Using PAT creds');
                var patCreds = credentials;
                this.authHandler = apim.getBasicHandler("OAuth", patCreds.token);
                break;
        }
        // TODO: validate url
        var purl = url.parse(collectionUrl);
        if (!purl.protocol || !purl.host) {
            trace('Invalid collection url');
            throw new Error('Invalid collection url');
        }
        // TODO: handle on prem /tfs
        this.accountUrl = purl.protocol + '//' + purl.host;
    }
    return TfsConnection;
})();
exports.TfsConnection = TfsConnection;
var result;
function getCollectionUrl() {
    trace('loader.getCollectionUrl');
    var defer = Q.defer();
    return this.getCachedUrl().then(function (url) {
        return url ? url : promptForUrl();
    });
    return defer.promise;
}
exports.getCollectionUrl = getCollectionUrl;
function getCachedUrl() {
    trace('loader.getCachedUrl');
    var defer = Q.defer();
    if (process.env['TFS_BYPASS_CACHE']) {
        trace('Skipping checking cache for collection url');
        defer.resolve('');
    }
    else {
        cache.getItem('cache', 'connection').then(function (url) {
            trace('Retrieved collection url from cache');
            defer.resolve(url);
        }).fail(function (err) {
            trace('No collection url found in cache');
            defer.resolve('');
        });
    }
    return defer.promise;
}
exports.getCachedUrl = getCachedUrl;
function promptForUrl() {
    trace('loader.promptForUrl');
    var defer = Q.defer();
    var promise = defer.promise;
    if (result) {
        defer.resolve(result);
        return promise;
    }
    var credInputs = [
        {
            name: 'collection',
            description: 'collection url',
            arg: 'collection',
            type: 'string',
            req: true
        }
    ];
    inputs.get(credInputs, function (err, result) {
        if (err) {
            trace('Url prompt failed: ' + err.message);
            defer.reject(err);
            return;
        }
        defer.resolve(result['collection']);
    });
    return promise;
}
exports.promptForUrl = promptForUrl;
